#!/usr/bin/env python
"""This file is automatically generated by generate_version_info
It uses the current working tree to determine the revision.
So don't edit it. :)
"""

version_info = {'branch_nick': u'build-branch',
 'build_date': '2010-10-11 17:46:54 +0200',
 'clean': False,
 'date': '2010-10-11 10:49:51 +0200',
 'revision_id': 'tca@gnu.org-20101011084951-luae11u5qfea9d2i',
 'revno': 1666}

revisions = {}

file_revisions = {}



if __name__ == '__main__':
    print 'revision: %(revno)d' % version_info
    print 'nick: %(branch_nick)s' % version_info
    print 'revision id: %(revision_id)s' % version_info
